@@ -3,7 +3,7 @@ BEGIN {
   $MooseX::MethodAttributes::AUTHORITY = 'cpan:FLORA';
 }
 BEGIN {
-  $MooseX::MethodAttributes::VERSION = '0.23';
+  $MooseX::MethodAttributes::VERSION = '0.25';
 }
 # ABSTRACT: code attribute introspection
 
@@ -28,17 +28,19 @@ sub init_meta {
         && does_role($meta->method_metaclass, 'MooseX::MethodAttributes::Role::Meta::Method')
         && does_role($meta->wrapped_method_metaclass, 'MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped');
 
-    $meta = Moose::Meta::Class->initialize( $for_class )
+    $meta = Moose::Meta::Class->create( $for_class )
         unless $meta;
 
-    $meta = Moose::Util::MetaRole::apply_metaclass_roles(
-        for_class                      => $for_class,
-        metaclass_roles                => ['MooseX::MethodAttributes::Role::Meta::Class'],
-        method_metaclass_roles         => ['MooseX::MethodAttributes::Role::Meta::Method'],
-        wrapped_method_metaclass_roles => ['MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped'],
+    $meta = Moose::Util::MetaRole::apply_metaroles(
+        for             => $for_class,
+        class_metaroles => {
+            class  => ['MooseX::MethodAttributes::Role::Meta::Class'],
+            method => ['MooseX::MethodAttributes::Role::Meta::Method'],
+            wrapped_method => [
+                'MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped'],
+        },
     );
 
-    $for_class = $meta->name;
     Moose::Util::MetaRole::apply_base_class_roles(
         for_class => $for_class,
         roles     => ['MooseX::MethodAttributes::Role::AttrContainer'],
@@ -92,7 +94,7 @@ Tomas Doran <bobtfish@bobtfish.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Florian Ragwitz.
+This software is copyright (c) 2011 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
