@@ -3,7 +3,7 @@ BEGIN {
   $MooseX::MethodAttributes::Role::AUTHORITY = 'cpan:FLORA';
 }
 BEGIN {
-  $MooseX::MethodAttributes::Role::VERSION = '0.23';
+  $MooseX::MethodAttributes::Role::VERSION = '0.25';
 }
 # ABSTRACT: code attribute introspection
 
@@ -26,12 +26,14 @@ sub init_meta {
     return $meta if $meta
         && does_role($meta, 'MooseX::MethodAttributes::Role::Meta::Role');
 
-    $meta = Moose::Meta::Role->initialize( $for_class )
+    $meta = Moose::Meta::Role->create( $for_class )
         unless $meta;
 
-    $meta = Moose::Util::MetaRole::apply_metaclass_roles(
-            for_class       => $meta->name,
-            metaclass_roles => [ 'MooseX::MethodAttributes::Role::Meta::Role' ],
+    $meta = Moose::Util::MetaRole::apply_metaroles(
+        for            => $meta->name,
+        role_metaroles => {
+            role => ['MooseX::MethodAttributes::Role::Meta::Role'],
+        },
     );
 
     ensure_all_roles($meta->name,
@@ -84,7 +86,7 @@ Tomas Doran <bobtfish@bobtfish.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Florian Ragwitz.
+This software is copyright (c) 2011 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
